function matlabbatch = teach_glm_subject(subjNum,derivs,doRun)

% teach_glm_subject(subjNum,derivs,doRun) performs/sets up a first level analysis. 
% Inputs:   subjNum -  number of subject (1 to 4)
%           derivs  -  use derivatis =1 or not =0
%           doRun   -  if 0 or not defined -> just create struct
%                      if 1 -> run directly
%                      if 2 -> rund interactively (open Batch editor with
%                      analysis)
%
% Outputs: matlabbatch  -  batch containing information about analysis.
% 
% Created: Oct 2018, Jakob Heinzle, Translational neuromodeling Unit, IBT
% University and ETH Zrich

if nargin < 3
    doRun =0;
end

% First, define, where the data is located. myDataFolder needs to point to the 
% folder where the Sub01 etc folders are located

myDataFolder = fullfile('E:','DocumentsNobox','MandMDaten','Data2018'); 
glmType= 'LRArrow'; % define which regressors to use.


pathData=fullfile(myDataFolder,sprintf('Sub%02.0f',subjNum));
if derivs % use derivatives
pathGLM=fullfile(pathData,'glm',sprintf('%s_derivs',glmType));
derivVec = [1 1];
funcReg =[1 2 3; 4 5 6];
nFuncReg = numel(funcReg);
else
    pathGLM=fullfile(pathData,'glm',sprintf('%s_noderivs',glmType));
    derivVec = [0 0];
    funcReg =[1;2];
    nFuncReg = numel(funcReg);
end

mkdir(pathGLM);

matlabbatch{1}.spm.stats.fmri_spec.dir = cellstr(pathGLM);
matlabbatch{1}.spm.stats.fmri_spec.timing.units = 'secs';
matlabbatch{1}.spm.stats.fmri_spec.timing.RT = 2.2;
matlabbatch{1}.spm.stats.fmri_spec.timing.fmri_t = 32;
matlabbatch{1}.spm.stats.fmri_spec.timing.fmri_t0 = 16;
for k=1:2 % cycle over runs.
    % load the data: Here s8wafmri..., Change next line if this is
    % different.
matlabbatch{1}.spm.stats.fmri_spec.sess(k).scans = cellstr(spm_select('ExtFPList',fullfile(pathData,'functional'),sprintf('s8wafmri%02.0f.nii',k),Inf));
matlabbatch{1}.spm.stats.fmri_spec.sess(k).cond = struct('name', {}, 'onset', {}, 'duration', {}, 'tmod', {}, 'pmod', {}, 'orth', {});
matlabbatch{1}.spm.stats.fmri_spec.sess(k).multi = cellstr(fullfile(pathData,'behav',sprintf('%sRegs%02.0f.mat',glmType,k)));
matlabbatch{1}.spm.stats.fmri_spec.sess(k).regress = struct('name', {}, 'val', {});
matlabbatch{1}.spm.stats.fmri_spec.sess(k).multi_reg = cellstr(fullfile(pathData,'functional',sprintf('rp_afmri%02.0f.txt',k)));
matlabbatch{1}.spm.stats.fmri_spec.sess(k).hpf = 128;
end
matlabbatch{1}.spm.stats.fmri_spec.fact = struct('name', {}, 'levels', {});
matlabbatch{1}.spm.stats.fmri_spec.bases.hrf.derivs = derivVec;
matlabbatch{1}.spm.stats.fmri_spec.volt = 1;
matlabbatch{1}.spm.stats.fmri_spec.global = 'None';
matlabbatch{1}.spm.stats.fmri_spec.mthresh = 0.8;
matlabbatch{1}.spm.stats.fmri_spec.mask = {''};
matlabbatch{1}.spm.stats.fmri_spec.cvi = 'AR(1)';
matlabbatch{2}.spm.stats.fmri_est.spmmat(1) = cfg_dep('fMRI model specification: SPM.mat File', substruct('.','val', '{}',{1}, '.','val', '{}',{1}, '.','val', '{}',{1}), substruct('.','spmmat'));
matlabbatch{2}.spm.stats.fmri_est.write_residuals = 0;
matlabbatch{2}.spm.stats.fmri_est.method.Classical = 1;
matlabbatch{3}.spm.stats.con.spmmat(1) = cfg_dep('Model estimation: SPM.mat File', substruct('.','val', '{}',{2}, '.','val', '{}',{1}, '.','val', '{}',{1}), substruct('.','spmmat'));
matlabbatch{3}.spm.stats.con.consess{1}.fcon.name = 'Main Effect';
matlabbatch{3}.spm.stats.con.consess{1}.fcon.weights = eye(nFuncReg);
matlabbatch{3}.spm.stats.con.consess{1}.fcon.sessrep = 'repl';

matlabbatch{3}.spm.stats.con.consess{2}.fcon.name = 'Effect of motion';
matlabbatch{3}.spm.stats.con.consess{2}.fcon.weights = [zeros(6,nFuncReg) eye(6)];
matlabbatch{3}.spm.stats.con.consess{2}.fcon.sessrep = 'repl';

matlabbatch{3}.spm.stats.con.consess{3}.tcon.name = 'Left > Right';
conVec = zeros(1,nFuncReg); conVec(funcReg(1,1))=1; conVec(funcReg(2,1))=-1;
matlabbatch{3}.spm.stats.con.consess{3}.tcon.weights = conVec;
matlabbatch{3}.spm.stats.con.consess{3}.tcon.sessrep = 'repl';

matlabbatch{3}.spm.stats.con.consess{4}.tcon.name = 'Right > Left';
conVec = zeros(1,nFuncReg); conVec(funcReg(1,1))=-1; conVec(funcReg(2,1))=1;
matlabbatch{3}.spm.stats.con.consess{4}.tcon.weights = conVec;
matlabbatch{3}.spm.stats.con.consess{4}.tcon.sessrep = 'repl';
matlabbatch{3}.spm.stats.con.consess{5}.fcon.name = 'Main Effect';
matlabbatch{3}.spm.stats.con.consess{5}.fcon.weights = eye(nFuncReg);
matlabbatch{3}.spm.stats.con.consess{5}.fcon.sessrep = 'none';
matlabbatch{3}.spm.stats.con.consess{6}.fcon.name = 'Main Effect';
matlabbatch{3}.spm.stats.con.consess{6}.fcon.weights = [zeros(nFuncReg,nFuncReg+6) eye(nFuncReg)];
matlabbatch{3}.spm.stats.con.consess{6}.fcon.sessrep = 'none';
matlabbatch{3}.spm.stats.con.consess{7}.tcon.name = 'Left > Right run1';
conVec = zeros(1,nFuncReg); conVec(funcReg(1,1))=1; conVec(funcReg(2,1))=-1;
matlabbatch{3}.spm.stats.con.consess{7}.tcon.weights = conVec;
matlabbatch{3}.spm.stats.con.consess{7}.tcon.sessrep = 'none';
matlabbatch{3}.spm.stats.con.consess{8}.tcon.name = 'Left > Right run2';
conVec = zeros(1,nFuncReg); conVec(funcReg(1,1))=1; conVec(funcReg(2,1))=-1;
matlabbatch{3}.spm.stats.con.consess{8}.tcon.weights = [zeros(1,nFuncReg+6) conVec];
matlabbatch{3}.spm.stats.con.consess{8}.tcon.sessrep = 'none';
matlabbatch{3}.spm.stats.con.consess{9}.tcon.name = 'Right > Left run1';
conVec = zeros(1,nFuncReg); conVec(funcReg(1,1))=-1; conVec(funcReg(2,1))=1;
matlabbatch{3}.spm.stats.con.consess{9}.tcon.weights = conVec;
matlabbatch{3}.spm.stats.con.consess{9}.tcon.sessrep = 'none';
matlabbatch{3}.spm.stats.con.consess{10}.tcon.name = 'Right > Left run2';
conVec = zeros(1,nFuncReg); conVec(funcReg(1,1))=-1; conVec(funcReg(2,1))=1;
matlabbatch{3}.spm.stats.con.consess{10}.tcon.weights = [zeros(1,nFuncReg+6) conVec];
matlabbatch{3}.spm.stats.con.consess{10}.tcon.sessrep = 'none';
matlabbatch{3}.spm.stats.con.delete = 0;

if doRun == 2
spm_jobman('initcfg');
spm_jobman('interactive',matlabbatch);
elseif doRun == 1
spm_jobman('initcfg');
spm_jobman('run',matlabbatch);
end
